@@ -116,7 +116,7 @@ class Scheduler:
         )
         print('Ps: to remove the "Scheduler", just replace .add by .delete')
 
-    def delete(self, path=None, all=False, debug=False):
+    def delete(self, path=None, all=True, debug=False):
         if self.manager.is_production():
             print("No delete done, you are in production\n")
             return
@@ -124,5 +124,5 @@ class Scheduler:
         self.manager.del_prod({"type": self.role, "path": current_file}, debug)
         print("🗑 Done! Your Scheduler has been remove from production.\n")
         if all is True:
-            self.clear(path)
-            self.clear_output(path)
+            self.clear(current_file, "all")
+            self.clear_output(current_file, "all")
